# Plotting

This module provides plotting utilities for visualizing GAM models and their components.
Plotting is perfomed using matplotlib, and returns the axes objects such that they
can be further customized as desired.

::: pymgcv.plot.plot_gam
::: pymgcv.plot.plot_continuous_1d
::: pymgcv.plot.plot_continuous_2d
::: pymgcv.plot.plot_categorical
